Learn R Programming

spemd (version 0.1-1)

extrema.irr: extrema.irr

Description

Internal function, finds regional extrema on a irregularly sampled data set

Usage

extrema.irr(data.set, gridded.data, neig = NULL, zcol = "z",
  duplicate = "remove", nb.nn = 4, thresh.extrema = 1, verbose = FALSE)

Arguments

data.set

.

gridded.data

.

neig

Neighbourhood object.

zcol

Name of the column containing the data.

duplicate

What to do with duplicates. Defaults to `remove`.

nb.nn

Number of nearest neighbours to take into account if data is on a grid. Defaults to 4.

thresh.extrema

Significative threshold for the extrema. Defaults to 1.

verbose

Prints progress information messages. Defaults to FALSE.