Internal function, finds regional extrema on a irregularly sampled data set
extrema.irr(data.set, gridded.data, neig = NULL, zcol = "z",
duplicate = "remove", nb.nn = 4, thresh.extrema = 1, verbose = FALSE).
.
Neighbourhood object.
Name of the column containing the data.
What to do with duplicates. Defaults to `remove`.
Number of nearest neighbours to take into account if data is on a grid. Defaults to 4.
Significative threshold for the extrema. Defaults to 1.
Prints progress information messages. Defaults to FALSE.